<?php


namespace App\Admin\Controllers;


use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;

class CdmsController extends AdminController
{

    /**
     * Make a form builder.
     *
     * @return Form
     */
    public function form()
    {
        $userModel = config('tenancy.database.users_model');
        $permissionModel = config('tenancy.database.permissions_model');
        $roleModel = config('tenancy.database.roles_model');

        $form = new Form(new $userModel());

        $userTable = config('tenancy.database.users_table');
        $connection = config('tenancy.database.connection');

        $form->display('id', 'ID');
        $form->text('username', trans('tenancy.username'))
            ->creationRules(['required', "unique:{$connection}.{$userTable}"])
            ->updateRules(['required', "unique:{$connection}.{$userTable},username,{{id}}"]);

        $form->text('name', trans('tenancy.name'))->rules('required');
        $form->image('avatar', trans('tenancy.avatar'));
        $form->password('password', trans('tenancy.password'))->rules('required|confirmed');
        $form->password('password_confirmation', trans('tenancy.password_confirmation'))->rules('required')
            ->default(function ($form) {
                return $form->model()->password;
            });

        $form->ignore(['password_confirmation']);

        $form->multipleSelect('roles', trans('tenancy.roles'))->options($roleModel::all()->pluck('name', 'id'));
        $form->multipleSelect('permissions', trans('tenancy.permissions'))->options($permissionModel::all()->pluck('name', 'id'));

        $form->display('created_at', trans('tenancy.created_at'));
        $form->display('updated_at', trans('tenancy.updated_at'));

        $form->saving(function (Form $form) {
            if ($form->password && $form->model()->password != $form->password) {
                $form->password = bcrypt($form->password);
            }
        });

        return $form;
    }
}
